Project hosting with Launchpad
==============================

`Launchpad`_ hosts the Savanna project. The Savanna project homepage on Launchpad is
http://launchpad.net/savanna.

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites. These sites include:

 * `Wiki`_
 * Gerrit (see :doc:`gerrit`)
 * Jenkins (see :doc:`jenkins`)

Mailing list
------------

The mailing list email is ``savanna-all@lists.launchpad.net``. To participate in the mailing list:

#. Join the `Savanna Team`_ on Launchpad.
#. Subscribe to the list on the `Savanna Team`_ page on Launchpad.

The mailing list archives are at https://lists.launchpad.net/savanna-all


Bug tracking
------------

Report Savanna bugs at https://bugs.launchpad.net/savanna

Feature requests (Blueprints)
-----------------------------

Savanna uses Launchpad Blueprints to track feature requests. Blueprints are at
https://blueprints.launchpad.net/savanna.

Technical support (Answers)
---------------------------

Savanna uses Launchpad Answers to track Savanna technical support questions. The Savanna
Answers page is at https://answers.launchpad.net/savanna

.. _Launchpad: http://launchpad.net
.. _Wiki: http://wiki.openstack.org/savanna
.. _Savanna Team: https://launchpad.net/~savanna-all